{% load staticfiles i18n %}<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta http-equiv="x-ua-compatible" content="ie=edge">
    <title>{% block title %}dj_waff - extra Django Widgets and Form Fields{% endblock title %}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="">
    <meta name="author" content="">

    <!-- HTML5 shim, for IE6-8 support of HTML5 elements -->
    <!--[if lt IE 9]>
  <script src="https://html5shim.googlecode.com/svn/trunk/html5.js"></script>
  <![endif]-->

    {% block css %}
        <!-- Latest compiled and minified CSS -->
        <link rel="stylesheet" href="https://cdn.rawgit.com/twbs/bootstrap/v4-dev/dist/css/bootstrap.css">

        <!-- Your stuff: Third-party css libraries go here -->

    {% endblock %}
</head>

<body>

<div class="m-b">
    <nav class="navbar navbar-dark navbar-static-top bg-inverse">
        <div class="container">
            <a class="navbar-brand" href="/">dj_waff</a>
            <button type="button" class="navbar-toggler hidden-sm-up pull-xs-right" data-toggle="collapse"
                    data-target="#bs-navbar-collapse-1">
                &#9776;
            </button>

            <!-- Collect the nav links, forms, and other content for toggling -->
            <div class="collapse navbar-toggleable-xs" id="bs-navbar-collapse-1">
                <ul class="nav navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link" href="/">Home</a>
                    </li>
                </ul>
            </div>
        </div>
    </nav>
</div>

<div class="container">

    {% if messages %}
        {% for message in messages %}
            <div class="alert {% if message.tags %}alert-{{ message.tags }}{% endif %}">{{ message }}</div>
        {% endfor %}
    {% endif %}

    {% block content %}
        <div class="row m-t-2">
            <p>Use this document as a way to quick start any new project.</p>
            <p>The current template is loaded from
                <code>dj_waff/example/templates/base.html</code>. </p>
            <p>Whenever you overwrite the contents of <code>dj_waff/dj_waff/urls.py</code> with your
                own content, you should see it here.</p>
        </div>
    {% endblock content %}

</div> <!-- /container -->

{% block modal %}{% endblock modal %}

<!-- Le javascript
================================================== -->
<!-- Placed at the end of the document so the pages load faster -->
{% block javascript %}
    <!-- Latest JQuery -->
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/2.2.0/jquery.min.js"></script>

    <!-- Tether - a requirement for Bootstrap tooltips -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/tether/1.2.0/js/tether.min.js"></script>

    <!-- Latest compiled and minified JavaScript -->
    <script src="https://cdn.rawgit.com/twbs/bootstrap/v4-dev/dist/js/bootstrap.js"></script>

    <!-- Your stuff: Third-party javascript libraries go here -->
    {% block extrajs %}

    {% endblock extrajs %}

{% endblock javascript %}
</body>
</html>

