#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_dj_waff
------------

Tests for `dj_waff` models module.
"""

from django.test import TestCase



class TestDj_waff(TestCase):

    def setUp(self):
        pass

    def test_something(self):
        self.assertEquals(True, True)

    def tearDown(self):
        pass
